# Élenchos

A [Nagios](https://www.nagios.org/) plugin framework in Python.

## Documentation

Documentation for developers who want to create Nagios plugins using Élenchos and the documentation for administrators
who want to install Nagios plugins build with Élenchos can be found at https://elenchos.readthedocs.io.

### License
This project is licensed under the terms of the MIT license.
